@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSClientAuthDialogs.cpp,v 1.25 2005/11/01 11:15:55 chpe Exp $
+ *  $Id: GtkNSSClientAuthDialogs.cpp,v 1.27 2006/02/02 22:25:18 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -25,6 +25,7 @@
 #include "config.h"
 
 #include "EphyUtils.h"
+#include "AutoJSContextStack.h"
 
 #include <nsIDOMWindow.h>
 #include <nsIServiceManager.h>
@@ -145,6 +146,11 @@ GtkNSSClientAuthDialogs::ChooseCertificate (nsIInterfaceRequestor *ctx,
 	char *msg, *markup_text;
 	PRUint32 i;
 
+	nsresult rv;
+	AutoJSContextStack stack;
+	rv = stack.Init ();
+	if (NS_FAILED (rv)) return rv;
+
 	nsCOMPtr<nsIDOMWindow> parent = do_GetInterface (ctx);
 	GtkWindow *gparent = GTK_WINDOW (EphyUtils::FindGtkParent (parent));
 
@@ -168,8 +174,7 @@ GtkNSSClientAuthDialogs::ChooseCertificate (nsIInterfaceRequestor *ctx,
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX(GTK_DIALOG (dialog)->action_area), 6);	
-	gtk_box_set_spacing (GTK_BOX(GTK_DIALOG (dialog)->vbox), 12);
+	gtk_box_set_spacing (GTK_BOX(GTK_DIALOG (dialog)->vbox), 14); /* 24 = 2 * 5 + 14 */
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 	
 	hbox = gtk_hbox_new (FALSE, 12);
