@@ -1,6 +1,7 @@
 /*
  *  Copyright (C) 2001,2002,2003 Philip Langdale
  *  Copyright (C) 2003 Marco Pesenti Gritti
+ *  Copyright (C) 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: MozRegisterComponents.cpp,v 1.37.2.1 2005/05/05 12:55:36 chpe Exp $
+ *  $Id: MozRegisterComponents.cpp,v 1.47 2006/03/05 22:07:52 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -29,6 +30,8 @@
 #include "MozDownload.h"
 #include "EphyContentPolicy.h"
 #include "EphySidebar.h"
+#include "EphyAboutModule.h"
+#include "EphyPromptService.h"
 
 #ifdef ENABLE_FILEPICKER
 #include "FilePicker.h"
@@ -59,6 +62,8 @@ NS_GENERIC_FACTORY_CONSTRUCTOR(MozGlobalHistory)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GPrintingPromptService)
 NS_GENERIC_FACTORY_CONSTRUCTOR(EphyContentPolicy)
 NS_GENERIC_FACTORY_CONSTRUCTOR(EphySidebar)
+NS_GENERIC_FACTORY_CONSTRUCTOR(EphyAboutModule)
+NS_GENERIC_FACTORY_CONSTRUCTOR(EphyPromptService)
 
 #ifdef ENABLE_FILEPICKER
 NS_GENERIC_FACTORY_CONSTRUCTOR(GFilePicker)
@@ -70,7 +75,11 @@ NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSDialogs)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSKeyPairDialogs)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSSecurityWarningDialogs)
 #endif
- 
+
+
+/* class information */ 
+NS_DECL_CLASSINFO(EphySidebar)
+
 static NS_METHOD
 RegisterContentPolicy(nsIComponentManager *aCompMgr, nsIFile *aPath,
 		      const char *registryLocation, const char *componentType,
@@ -186,8 +195,48 @@ static const nsModuleComponentInfo sAppComps[] = {
 		EPHY_SIDEBAR_CID,
 		NS_SIDEBAR_CONTRACTID,
 		EphySidebarConstructor,
-		RegisterSidebar
+		RegisterSidebar,
+		nsnull /* no unregister func */,
+		nsnull /* no factory destructor */,
+		NS_CI_INTERFACE_GETTER_NAME(EphySidebar),
+		nsnull /* no language helper */,
+		&NS_CLASSINFO_NAME(EphySidebar),
+		nsIClassInfo::DOM_OBJECT
 	},
+	{
+		EPHY_ABOUT_EPIPHANY_CLASSNAME,
+		EPHY_ABOUT_MODULE_CID,
+		EPHY_ABOUT_EPIPHANY_CONTRACTID,
+		EphyAboutModuleConstructor
+	},
+	{
+		EPHY_ABOUT_RECOVER_CLASSNAME,
+		EPHY_ABOUT_MODULE_CID,
+		EPHY_ABOUT_RECOVER_CONTRACTID,
+		EphyAboutModuleConstructor
+	},
+#ifdef HAVE_GECKO_1_8
+	{
+		EPHY_ABOUT_NETERROR_CLASSNAME,
+		EPHY_ABOUT_MODULE_CID,
+		EPHY_ABOUT_NETERROR_CONTRACTID,
+		EphyAboutModuleConstructor
+	},
+#endif
+	{
+		EPHY_PROMPT_SERVICE_CLASSNAME,
+		EPHY_PROMPT_SERVICE_IID,
+		"@mozilla.org/embedcomp/prompt-service;1",
+		EphyPromptServiceConstructor
+	},
+#ifdef HAVE_NSINONBLOCKINGALERTSERVICE_H
+	{
+		EPHY_PROMPT_SERVICE_CLASSNAME,
+		EPHY_PROMPT_SERVICE_IID,
+		"@mozilla.org/embedcomp/nbalert-service;1",
+		EphyPromptServiceConstructor
+	},
+#endif /* HAVE_NSINONBLOCKINGALERTSERVICE_H */
 };
 
 #if defined(HAVE_MOZILLA_PSM) && !defined(HAVE_GECKO_1_8)
