@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-toolbars-model.c,v 1.37 2005/10/16 20:29:16 chpe Exp $
+ *  $Id: ephy-toolbars-model.c,v 1.39 2006/02/04 10:43:24 paharvey Exp $
  */
 
 #include "config.h"
@@ -80,7 +80,7 @@ save_changes_idle (EphyToolbarsModel *model)
 {
 	LOG ("Saving toolbars model");
 
-	egg_toolbars_model_save
+	egg_toolbars_model_save_toolbars
 		(EGG_TOOLBARS_MODEL (model),
 		 model->priv->xml_file,
 		 EPHY_TOOLBARS_XML_VERSION);
@@ -182,27 +182,9 @@ ephy_toolbars_model_load (EphyToolbarsModel *model)
 	gboolean success;
 	int i;
 
-	egg_toolbars_model_set_n_avail (eggmodel, "NavigationBack", 1);
-	egg_toolbars_model_set_n_avail (eggmodel, "NavigationForward", 1);
-	egg_toolbars_model_set_n_avail (eggmodel, "NavigationUp", 1);
-	egg_toolbars_model_set_n_avail (eggmodel, "ViewStop", 1);
-	egg_toolbars_model_set_n_avail (eggmodel, "ViewReload", 1);
-	egg_toolbars_model_set_n_avail (eggmodel, "GoHome", 1);
-	egg_toolbars_model_set_n_avail (eggmodel, "GoHistory", 1);
-	egg_toolbars_model_set_n_avail (eggmodel, "GoBookmarks", 1);
-	egg_toolbars_model_set_n_avail (eggmodel, "FileNewTab", 1);
-	egg_toolbars_model_set_n_avail (eggmodel, "FileNewWindow", 1);
-	egg_toolbars_model_set_n_avail (eggmodel, "FileOpen", 1);
-	egg_toolbars_model_set_n_avail (eggmodel, "FileSaveAs", 1);
-	egg_toolbars_model_set_n_avail (eggmodel, "FilePrint", 1);
-	egg_toolbars_model_set_n_avail (eggmodel, "FileBookmarkPage", 1);
-	egg_toolbars_model_set_n_avail (eggmodel, "ViewFullscreen", 1);
-	egg_toolbars_model_set_n_avail (eggmodel, "EditFind", 1);
-	egg_toolbars_model_set_n_avail (eggmodel, "Location", 1);
-	egg_toolbars_model_set_n_avail (eggmodel, "ToolbarGo", 1);
-	egg_toolbars_model_set_n_avail (eggmodel, "Zoom", 1);
+	egg_toolbars_model_load_names (eggmodel, ephy_file ("epiphany-toolbar.xml"));
   
-	success = egg_toolbars_model_load (eggmodel, model->priv->xml_file);
+	success = egg_toolbars_model_load_toolbars (eggmodel, model->priv->xml_file);
 	LOG ("Loading the toolbars was %ssuccessful", success ? "" : "un");
 
 	/* maybe an old format, try to migrate: load the old layout, and
@@ -215,7 +197,7 @@ ephy_toolbars_model_load (EphyToolbarsModel *model)
 		old_xml = g_build_filename (ephy_dot_dir (),
 					    "epiphany-toolbars-2.xml",
 					    NULL);
-		success = egg_toolbars_model_load (eggmodel, old_xml);
+		success = egg_toolbars_model_load_toolbars (eggmodel, old_xml);
 		g_free (old_xml);
 
 		if (success == TRUE)
@@ -223,7 +205,7 @@ ephy_toolbars_model_load (EphyToolbarsModel *model)
 			old_xml = g_build_filename (ephy_dot_dir (),
 						    "epiphany-bookmarksbar.xml",
 						    NULL);
-			egg_toolbars_model_load (eggmodel, old_xml);
+			egg_toolbars_model_load_toolbars (eggmodel, old_xml);
 			g_free (old_xml);
 		}
 
@@ -237,7 +219,7 @@ ephy_toolbars_model_load (EphyToolbarsModel *model)
 		old_xml = g_build_filename (ephy_dot_dir (),
 					    "epiphany-toolbars.xml",
 					    NULL);
-		success = egg_toolbars_model_load (eggmodel, old_xml);
+		success = egg_toolbars_model_load_toolbars (eggmodel, old_xml);
 		g_free (old_xml);
 
 		LOG ("Migration was %ssuccessful", success ? "" : "un");
@@ -246,7 +228,7 @@ ephy_toolbars_model_load (EphyToolbarsModel *model)
 	/* Still no success, load the default toolbars */
 	if (success == FALSE)
 	{
-		success = egg_toolbars_model_load
+		success = egg_toolbars_model_load_toolbars
 				(eggmodel, ephy_file ("epiphany-toolbar.xml"));
 		LOG ("Loading the default toolbars was %ssuccessful", success ? "" : "un");
 	}
